@@ -19,4 +19,7 @@ population = [
     {'Name': 'OS Engineer large frame'},   # For large sheet sizes (D, E, A2-A0)
     {'Name': 'OS Engineer medium frame'},  # For medium sheet sizes (tabloid, A3)
     {'Name': 'TRI MBSE large frame'},  # For large sheet sizes (D, E, A2-A0)
+
+    # Diagnostic
+    {'Name': 'Grid Diagnostic'},  # To display a grid of rows and columns
 ]
\ No newline at end of file
