@@ -70,7 +70,7 @@ class Diagram:
         if show_grid:
             # Create the grid layer
             self.Canvas.Tablet.add_layer(name='grid', presentation='default', drawing_type='Grid Diagnostic')
-        self.Grid = Grid(diagram=self)  # Start with an empty grid
+        self.Grid = Grid(diagram=self, show=show_grid)  # Start with an empty grid
         self.Padding = padding
         self.Origin = Position(
             x=self.Canvas.Margin.left + self.Padding.left,
